==> haskell-enummapset-0.7.3.0-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enummapset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enummapset
version:              0.7.3.0
visibility:           public
id:                   enummapset-0.7.3.0-1gmngKkXPBr5BsaqQdi4wk
key:                  enummapset-0.7.3.0-1gmngKkXPBr5BsaqQdi4wk
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Michal Terepeta and others
homepage:             https://github.com/Mikolaj/enummapset
synopsis:             IntMap and IntSet with Enum keys/elements.
description:
    This package contains simple wrappers around '\''Data.IntMap'\'' and
    '\''Data.IntSet'\'' with '\''Enum'\'' keys and elements respectively.
    Especially useful for '\''Int'\''s wrapped with `newtype`.

category:             Data Structures
abi:                  87161676d9b2d2ba500a735cfb54ba5b
exposed:              True
exposed-modules:
    Data.EnumMap Data.EnumMap.Lazy Data.EnumMap.Strict Data.EnumSet

hidden-modules:       Data.EnumMap.Base
import-dirs:          /usr/lib/ghc-9.4.8/site-local/enummapset-0.7.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/enummapset-0.7.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/enummapset-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enummapset
hs-libraries:         HSenummapset-0.7.3.0-1gmngKkXPBr5BsaqQdi4wk
depends:
    aeson-2.1.2.1-4CVR04TmBAJCS7ApojWVjB base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-enummapset/html/enummapset.haddock
haddock-html:         /usr/share/doc/haskell-enummapset/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enummapset-0.7.3.0-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enummapset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enummapset
version:              0.7.3.0
visibility:           public
id:                   enummapset-0.7.3.0-6olEuQyi3a1L37e8J1KhQ0
key:                  enummapset-0.7.3.0-6olEuQyi3a1L37e8J1KhQ0
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Michal Terepeta and others
homepage:             https://github.com/Mikolaj/enummapset
synopsis:             IntMap and IntSet with Enum keys/elements.
description:
    This package contains simple wrappers around '\''Data.IntMap'\'' and
    '\''Data.IntSet'\'' with '\''Enum'\'' keys and elements respectively.
    Especially useful for '\''Int'\''s wrapped with `newtype`.

category:             Data Structures
abi:                  67668b2aeb6ad75ba1f5304f74e66e78
exposed:              True
exposed-modules:
    Data.EnumMap Data.EnumMap.Lazy Data.EnumMap.Strict Data.EnumSet

hidden-modules:       Data.EnumMap.Base
import-dirs:          /usr/lib/ghc-9.4.8/site-local/enummapset-0.7.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/enummapset-0.7.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/enummapset-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enummapset
hs-libraries:         HSenummapset-0.7.3.0-6olEuQyi3a1L37e8J1KhQ0
depends:
    aeson-2.1.2.1-KaceSWeAWkBK9urIr7RMHq base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-enummapset/html/enummapset.haddock
haddock-html:         /usr/share/doc/haskell-enummapset/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
